=============================================================
Sadie: Stochastic Agents in DIscrete time and Euclidean space
=============================================================


.. image:: https://img.shields.io/pypi/v/sadie.svg
        :target: https://pypi.python.org/pypi/sadie

.. image:: https://github.com/chrisvoncsefalvay/sadie/workflows/Run%20Tox/badge.svg
        :target: https://github.com/chrisvoncsefalvay/sadie/workflows/Run%20Tox/
        :alt: Tox check status

.. image:: https://readthedocs.org/projects/sadie/badge/?version=latest
        :target: https://sadie.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/github/license/chrisvoncsefalvay/sadie
        :target: https://github.com/chrisvoncsefalvay/sadie/LICENSE
        :alt: GitHub


Sadie is an agent-based modelling environment for stochastic agents in discrete time in Euclidean space. It is intended
to serve as a simple, convenient replacement for more complex agent-based modelling frameworks such as Repast and Mesa
where customisation and adaptation to specific use cases is required. In particular, Sadie is designed for simulating
random walks in various complex interactions, including Lévy walks, avoidant walks, homesick and other stochastic
mobility models in Euclidean space.

* Free software: MIT license
* Documentation: https://sadie.readthedocs.io.


Features
--------

* Spatial agents, including various random walk agents
* Targetable objects, with target-following ability
* Model objects with extensive ability to report and collate data
* Easily extensible over a wide range of use cases in mobility, analytics, foraging, spatial statistics, epidemiology and many other areas

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
